.. highlight:: shell



===============
Example Results
===============

Comparison Plots
-----------------

Boxplot for AUC values per dataset:

.. image:: ./images/comparison_auc_per_dataset.png
   :width: 500 px



Boxplot for AUC values per dataset fold:

.. image:: ./images/comparison_auc_per_fold.png
   :width: 500 px



Boxplot for ACC values per dataset:

.. image:: ./images/comparison_accuracy_per_dataset.png
   :width: 500 px



Boxplot for ACC values per dataset fold:

.. image:: ./images/comparison_accuracy_per_fold.png
   :width: 500 px




Comparison Tables
-----------------

.. image:: ./images/result_tables.png
   :width: 700 px


Info Tables
-----------

.. image:: ./images/info_tables.png
   :width: 500 px
